@@ -31,7 +31,7 @@
 
 // Use Apple's chooser
 #ifdef __APPLE__
-#include "Fl_Native_File_Chooser_MAC.cxx"
+#include "MAC_chooser.cxx"
 #endif
 
 // All else falls back to FLTK's own chooser
@@ -39,4 +39,12 @@
 #include "Fl_Native_File_Chooser_FLTK.cxx"
 #endif
 
+#else
+
+// Use Apple's chooser
+#ifdef __APPLE__
+#include "MAC_chooser.cxx"
+#endif
+
+
 #endif
