@@ -12,7 +12,7 @@ using namespace std;
 
 struct FIELD {
   int  type;
-  string *name;
+  const char *name;
   Fl_Check_Button **btn;
 };
 
