@@ -4,6 +4,8 @@
 #ifndef _WEFAX_PIC_H
 #define _WEFAX_PIC_H
 
+#include <FL/Fl_Double_Window.H>
+
 class Fl_Menu_ ;
 
 class wefax ;
@@ -39,4 +41,7 @@ public:
 	static void restore_max_lines(void);
 };
 
+extern Fl_Double_Window *wefax_pic_tx_win;
+extern Fl_Double_Window *wefax_pic_rx_win;
+
 #endif // _WEFAX_PIC_H
