@@ -318,7 +318,7 @@ int comparerecs (const void *rp1, const void *rp2) { // rp1 needle, rp2 haystack
 
 static void rxtext(const char *s)
 {
-	ReceiveText->add(s);
+	ReceiveText->addstr(s);
 }
 
 void merge_recs( cQsoDb *db, cQsoDb *mrgdb ) // (haystack, needle)
@@ -362,19 +362,21 @@ void merge_recs( cQsoDb *db, cQsoDb *mrgdb ) // (haystack, needle)
 				if (comparerecs(db->getRec(db->nbrRecs()-1), mrgdb->getRec(m)) < 0) {
 					db->qsoNewRec(mrgdb->getRec(m));
 					merged->qsoNewRec(mrgdb->getRec(m));
-				} else
+				} else {
 					reject->qsoNewRec(mrgdb->getRec(m));
+				}
 				m++;
 			}
 		} else if (n == N) {
 			if (db->nbrRecs() == 0) {
 				db->qsoNewRec(mrgdb->getRec(m));
 				merged->qsoNewRec(mrgdb->getRec(m));
-			} else if (comparerecs(db->getRec(db->nbrRecs()-1), mrgdb->getRec(m)) < 0) {
+			} else if (comparerecs(db->getRec(db->nbrRecs()-1), mrgdb->getRec(m)) != 0) {
 				db->qsoNewRec(mrgdb->getRec(m));
 				merged->qsoNewRec(mrgdb->getRec(m));
-			} else
+			} else {
 				reject->qsoNewRec(mrgdb->getRec(m));
+			}
 			m++;
 		} else {
 			db->qsoNewRec(copy->getRec(n));
