@@ -68,6 +68,23 @@
 #  include <fcntl.h>
 #endif
 
+// this tests depends on a modified FL/filename.H in the Fltk-1.3.0
+// change
+//#  if defined(WIN32) && !defined(__CYGWIN__) && !defined(__WATCOMC__)
+// to
+//#  if defined(WIN32) && !defined(__CYGWIN__) && !defined(__WATCOMC__) && !defined(__WOE32__)
+
+#ifdef __MINGW32__
+#	if FLDIGI_FLTK_API_MAJOR == 1 && FLDIGI_FLTK_API_MINOR < 3
+#		undef dirent
+#		include <dirent.h>
+#	else
+#		include <dirent.h>
+#	endif
+#else
+#	include <dirent.h>
+#endif
+
 using namespace std;
 
 
@@ -302,6 +319,7 @@ void configuration::writeDefaultsXML()
 
 static void log_excluded_modes(void)
 {
+return;
 	struct {
 		mode_set_t* modes;
 		const char* msgstr;
